@@ -23,12 +23,20 @@
 #    return(TRUE)
 #}
 
+.onAttach <- function(libname, pkgname) {
+    packageStartupMessage(paste("This is mboost 2.2-0.\n",
+                                " See NEWS for a complete list of changes.\n",
+                                " Note: The default for the computation",
+                                "of the degrees of freedom has been changed!\n"))
+    return(TRUE)
+}
+
 .onLoad <- function(libname, pkgname) {
     if (options("expressions")[[1]] <= 5000)
         options(expressions = 10000)  ### increase maximum number of expressions
     options(mboost_useMatrix = TRUE, ### allow for Matrix package?
             mboost_indexmin = 10000, ### handle ties for n > 10000
-            mboost_dftraceS = TRUE,  ### df = trace(S) or df = trace(2 S - StS)
+            mboost_dftraceS = FALSE,  ### df = trace(S) or df = trace(2 S - StS)
             mboost_lambdaMax = 1e+15,### maximum value for lambda as used in df2lambda
             mboost_Xmonotone = FALSE,### don't force monotonicity in %X%
             mboost_eps = 10e-10)     ### factor for dmat in df2lambda
