@@ -438,3 +438,21 @@ Xold <- matrix(0, nrow = length(regions), ncol = ncol(K))
 for (i in 1:length(regions))
     Xold[i, which(districts == regions[i])] <- 1
 stopifnot(all(X == Xold))
+
+
+## check handling of missing values
+y <- yNa <- rnorm(100)
+x1 <- rnorm(100)
+x2 <- rnorm(100)
+
+yNa[1] <- NA
+coef(mboost(yNa ~ x1))
+
+yNa <- y
+yNa[2] <- NaN
+coef(mboost(yNa ~ x1))
+
+x1[1] <- NA
+mod <- mboost(y ~ bols(x1) + bbs(x1) + brandom(x1) +
+                  bspatial(x1, x2) + brad(x1, x2, knots = 20) +
+                  bmono(x1) +  buser(x1, K = 1, lambda = 0) + x2)
